| Title: | Baltimore City Public Schools |
|---|---|
| Description: | Provides access to demographic, enrollment, and survey data on Baltimore City Public School System (BCPSS). |
| Authors: | Eli Pousson [aut, cre] (ORCID: <https://orcid.org/0000-0001-8280-1706>) |
| Maintainer: | Eli Pousson <[email protected]> |
| License: | CC0 |
| Version: | 0.2.0.9000 |
| Built: | 2026-05-10 06:08:31 UTC |
| Source: | https://github.com/elipousson/bcpss |
The Maryland State Department of Education is required to report "accountability data" under the 2015 federal Every Student Succeeds Act (ESSA). Maryland's plan for an accountability system that complies with the ESSA was approved by the U.S. Department of Education in early 2018. Overall, The accountability system has two parts: academic indicators, which make up 65 possible points in the system, and measures of school quality and student success, which are 35 possible points. The star rating and total points are summary measures based on a broad selection of performance indicators to measure how schools are doing.
Detailed data is available for download through the MSDE website. Howard County Public School System (HCPSS) provides an accessible explanation of the accountability data on their website: https://www.hcpss.org/about-us/essa/
accountability_SY1920accountability_SY1920
A data frame with 160 rows and 8 variables:
school_yearSchool year
school_numberSchool number
school_nameSchool name
star_ratingStar rating
total_points_earned_percentageTotal points earned (as a percentage)
percentile_rank_elementaryStatewide percentile rank for elementary school grade band
percentile_rank_middleStatewide percentile rank for middle school grade band
percentile_rank_highStatewide percentile rank for high school grade band
Attendance data from the Maryland State Department of Education (MSDE). Raw
CSV data files with the full state enrollment data are available in the
inst/extdata folder. Any percent variables with a value of 95 percent
should be interpreted as equivalent at or above 95 percent. Any percent
variables with a value of 5 percent should be interpreted as equivalent to at
or below 5 percent. Chronic absenteeism data is not available prior to 2018
when the federal Every Student Succeeds Act (passed in 2015) went into effect
and Maryland began to include the chronic absenteeism rate in the state's
annual academic report cards. Variable definitions are based on the
definitions from the MSDE website.
attendance_msde_SY0919attendance_msde_SY0919
A data frame with 3,197 rows and 15 variables:
school_yearSchool year or academic year, e.g. 2019 for 2019-2020 school year
school_numberSchool number (0 indicates all schools)
school_nameSchool name
grade_bandGrade band (school type)
attend_rate_pctAttendance rate as defined as the average daily attendance rate of students in the school and grade band, including special education students
days_attended_cntTotal number of students in attendance from the first day of school through April 13th
days_member_cntTotal number of students registered to attend from the first day of school through April 13th
fewer_5_pctPercent of students absentee rate is the percentage of students absent from school for five or fewer days between the first day of the school year and the last day of the school year
fewer_5_cntCount of students absentee rate is the percentage of students absent from school for five or fewer days between the first day of the school year and the last day of the school year
more_20_pctPercent of students absentee rate is the percentage of students absent from school for twenty or more days between the first day of the school year and the last day of the school year
more_20_cntNumber of students absentee rate is the percentage of students absent from school for twenty or more days between the first day of the school year and the last day of the school year
more_90_member_cntNumber of students with an attendance rate of 90 percent or more (?)
chronic_absentee_cntNumber of students expected to attend school for at least 10 days who were absent 10 percent or more of the school days while enrolled at that school
chronic_absentee_denomNumber of students who are expected to attend school for at least 10 days in the school year
chronic_absentee_pctChronic absenteeism rate as defined as the percent of students expected to attend school for at least 10 days who were absent 10 percent or more of the school days while enrolled at that school
Boundaries for Baltimore City Public School elementary school attendance
zones for the 2020-2021 school year. The program_number variable is
equivalent to the school_number variable used in the demographic and survey
datasets.
bcps_es_zones_SY2021bcps_es_zones_SY2021
A data frame with 96 rows and 5 variables:
zone_numberProgram zone number
zone_nameProgram zone name
program_numberProgram number (school number)
program_name_shortProgram name (short)
geometryMultipolygon geometry for zone boundaries
https://services3.arcgis.com/mbYrzb5fKcXcAMNi/ArcGIS/rest/services/BCPSZones_2021/FeatureServer/0
Boundaries for Baltimore City Public School elementary school attendance
zones for the 2021-2022 school year. The program_number variable is
equivalent to the school_number variable used in the demographic and survey
datasets.
bcps_es_zones_SY2122bcps_es_zones_SY2122
A data frame with 92 features and 5 variables:
zone_numberProgram zone number
zone_nameProgram zone name
program_numberProgram number (school number)
program_name_shortProgram name (short)
geometryMultipolygon geometry for zone boundaries
https://services3.arcgis.com/mbYrzb5fKcXcAMNi/ArcGIS/rest/services/BCPSZones_2122/FeatureServer/0
Boundaries for Baltimore City Public School elementary school attendance
zones for the 2022-2023 school year. The program_number variable is
equivalent to the school_number variable used in the demographic and survey
datasets.
bcps_es_zones_SY2223bcps_es_zones_SY2223
A data frame with 92 rows and 9 variables:
zone_numberProgram zone number
zone_nameProgram zone name
program_numberProgram number (school number)
program_name_shortProgram name (short)
ms_feederFlag for elementary school programs that feed into a middle school
lower_gradesDescription for lower grades
upper_gradesDescription for higher grades (identifying middle school that the elementary feeds into if appropriate)
quadrantQuadrant of Baltimore City
geometryMultipolygon geometry for zone boundaries
Boundaries for Baltimore City Public School elementary school attendance
zones for the 2023-2024 school year. The program_number variable is
equivalent to the school_number variable used in the demographic and survey
datasets.
bcps_es_zones_SY2324bcps_es_zones_SY2324
A data frame with 90 rows and 6 variables:
zone_numberProgram zone number
zone_nameProgram zone name
program_numberProgram number (school number)
program_nameProgram name
program_name_shortProgram name (short)
upper_gradesDescription for higher grades (identifying middle school that the elementary feeds into if appropriate)
geometryMultipolygon geometry for zone boundaries
Locations for Baltimore City Public School buildings for the 2019-2020
school year. The program_number variable is equivalent to the school_number
variable used in the demographic and survey datasets.
bcps_programs_SY1920bcps_programs_SY1920
A data frame with 174 rows and 11 variables:
program_numberProgram number (school number)
program_nameProgram name
program_name_shortProgram name (short)
grade_bandGrade band for program
management_typeSchool management type
swingLogical indicator for program at swing site
swing_building_numberBuilding number for swing site
colocatedLogical indicator for programs colocated with another program
council_districtBaltimore City Council District Number
legislative_districtMaryland Legislative District
geometryPoint geometry for program/school locations
Locations for Baltimore City Public School buildings and programs for the
2020-2021 school year. The program_number variable is equivalent to the
school_number variable used in the demographic and survey datasets.
bcps_programs_SY2021bcps_programs_SY2021
A data frame with 165 rows and 18 variables:
program_numberProgram number (school number)
program_name_shortProgram name (short)
grade_bandGrade band for program
management_typeSchool management type
categoryGrade category
swingLogical indicator for program at swing site
swing_building_numberBuilding number for swing site
colocatedLogical indicator for programs colocated with another program
two_buildingsLogical indicator for programs with two buildings at one site
home_building...
council_districtBaltimore City Council District Number
legislative_districtMaryland Legislative District
congressional_districtU.S. Congressional District
planning_areaPlanning area, Baltimore City Department of Planning
quadrantQuadrant
zone_numberProgram zone number
zone_nameProgram zone name
geometryPoint geometry for program/school locations
https://services3.arcgis.com/mbYrzb5fKcXcAMNi/ArcGIS/rest/services/SY2021_Programs/FeatureServer
Locations for Baltimore City Public School buildings and programs for the
2021-2022 school year. The program_number variable is equivalent to the
school_number variable used in the demographic and survey datasets.
bcps_programs_SY2122bcps_programs_SY2122
A data frame with 165 rows and 18 variables:
program_numberProgram number (school number)
program_name_shortProgram name (short)
grade_bandGrade band for program
management_typeSchool management type
categoryGrade category
swingLogical indicator for program at swing site
swing_building_numberBuilding number for swing site
geometryPoint geometry for program/school locations
Locations for Baltimore City Public School buildings and programs for the
2022-2023 school year. The program_number variable is equivalent to the
school_number variable used in the demographic and survey datasets.
bcps_programs_SY2223bcps_programs_SY2223
A data frame with 159 rows and 8 variables:
program_numberProgram number (school number)
program_name_shortProgram name (short)
grade_bandGrade band for program
management_typeSchool management type
categoryGrade category
swingLogical indicator for program at swing site
swing_building_numberBuilding number for swing site
geometryPoint geometry for program/school locations
https://services3.arcgis.com/mbYrzb5fKcXcAMNi/ArcGIS/rest/services/SY2223_Programs/FeatureServer/0
Baltimore City Public Schools Surplus School Buildings
bcps_surplus_schoolsbcps_surplus_schools
A data frame with 40 rows and 15 variables:
posPosition/sort order
idIdentifier
building_nameBuilding name
primary_building_yearPrimary building year of construction
addressBuilding street address
school_nameSchool name
school_numberSchool number
school_closure_yearYear school closed
surplus_yearYear surplussed
status_sy20Status (Fall 2020)
status_sy22Status (Fall 2022)
building_sq_ftBuilding interior area (square feet)
property_acresProperty area (acres)
flag_property_acresFlag for properties with shared campus and inaccurate acreage
urlURL for Baltimore City Surplus Schools website or related ArcGIS Feature Layer
geometryPOINT geometry with building location
Baltimore City Department of Planning - FeatureLayer
This data is a subset of the marylandedu::msde_attendance dataset.
bcpss_attendancebcpss_attendance
A data frame with 5,585 rows and 18 variables:
yearSchool year or academic year, e.g. 2019 for 2019-2020 school year
school_numberSchool number (0 indicates all schools)
school_nameSchool name
grade_rangeGrade range used for attendance details.
attend_rate_pctAttendance rate as defined as the average daily attendance rate of students in the school and grade band, including special education students
days_attended_countTotal number of students in attendance from the first day of school through April 13th
days_member_countTotal number of students registered to attend from the first day of school through April 13th
fewer_5_pctPercent of students absentee rate is the percentage of students absent from school for five or fewer days between the first day of the school year and the last day of the school year
fewer_5_countCount of students absentee rate is the percentage of students absent from school for five or fewer days between the first day of the school year and the last day of the school year
more_20_pctPercent of students absentee rate is the percentage of students absent from school for twenty or more days between the first day of the school year and the last day of the school year
more_20_countNumber of students absentee rate is the percentage of students absent from school for twenty or more days between the first day of the school year and the last day of the school year
more_90_member_countNumber of students with an attendance rate of 90 percent or more
chronic_absentee_countNumber of students expected to attend school for at least 10 days who were absent 10 percent or more of the school days while enrolled at that school
chronic_absentee_denomNumber of students who are expected to attend school for at least 10 days in the school year
chronic_absentee_pctChronic absenteeism rate as defined as the percent of students expected to attend school for at least 10 days who were absent 10 percent or more of the school days while enrolled at that school
date_createdDate record created.
lss_numberLocal school system (LSS) number as integer. NA is used in place of a LSS number for statewide data. Older LEA numbers are combined with LSS numbers in this dataset.
lss_nameLocal school system (LSS) names (typically same as county name). "State" is used in place of a LSS name for statewide data. Older LEA names are combined with LSS names in this dataset.
Buildings and programs within BCPSS. Note that each row is a program (not a building).
bcpss_buildings_SY2122bcpss_buildings_SY2122
A data frame with 173 rows and 18 variables:
psc_numberPSC Number
bldg_numberBuilding number
bldg_nameBuilding name
program_numberProgram number
program_nameProgram name
management_typeManagement type
addressAddress
srcSRC (State Rated Capacity)
bldg_enrollmentTotal building enrollment
program_enrollmentProgram enrollment
utilization_pctUtilitization (% of SRC)
acresAcres
bldg_sqftBuilding sq. feet
fci_scoreFCI Score (physical condition)
notesBuilding notes
swing_spaceSwing space indicator
bcpss_ownedBCPSS owned building indicator
year_builtYear built
This data is a subset of the marylandedu::msde_enrollment dataset include
all data where the lss_name is "Baltimore City". This data does not include
the SEED School of Maryland which is located within Baltimore City. It is
recommended you use this data instead of enrollment_msde_SY0919 as the name
of this object will remain the same when current enrollment data is appended
on an annual basis. Updated 2025-07-03.
bcpss_enrollmentbcpss_enrollment
A data frame with 38,059 rows and 10 variables:
yearSchool or academic year for enrollment count, e.g. 2019 data is from the start of the 2019-2020 school year.
school_numberSchool number as integer (0 indicates all schools)
school_nameSchool name
enrolled_countNumber of students registered to attend the school at the start of the year in the grade or grade range as integer. Typically enrollment count is as of September 30.
gradeGrades from Prekindergarden (PK) to Grade 12
grade_rangeall elementary school Grades, all middle school grades, all high school grades, or all grades (total enrollment). May also be used as a label for grade.
raceRace/ethnicity. Enrollment by race/ethnicity is only available across all grades for years since 2020. "All" is used for data prior to 2020.
date_createdDate record created.
lss_numberLocal school system (LSS) number as integer. NA is used in place of a LSS number for statewide data. Older LEA numbers are combined with LSS numbers in this dataset.
lss_nameLocal school system (LSS) names (typically same as county name). "State" is used in place of a LSS name for statewide data. Older LEA names are combined with LSS names in this dataset.
Student mobility data from the Maryland State Department of Education (MSDE). A subset of the marylandedu::msde_student_mobility dataset.
bcpss_student_mobilitybcpss_student_mobility
A data frame with 5586 rows and 14 variables:
yearSchool or academic year for enrollment count, e.g. 2019 data is from the start of the 2019-2020 school year.
school_numberSchool number as integer (0 indicates all schools)
school_nameSchool name
school_typeSchool type (e.g. Elementary, Middle, High)
mobile_pctStudent total mobility rate
entry_pctStudent entry mobility rate
exit_pctStudent exit mobility rate
mobile_countSudent entry and exit count
entry_countStudent entry count
exit_countStudent exit count
avg_enrolled_countAverage daily student enrollment.
date_createdDate record created.
lss_numberLocal school system (LSS) number as integer. NA is used in place of a LSS number for statewide data. Older LEA numbers are combined with LSS numbers in this dataset.
lss_nameLocal school system (LSS) names (typically same as county name). "State" is used in place of a LSS name for statewide data. Older LEA names are combined with LSS names in this dataset.
The Maryland School Survey was administered for the first time in spring 2019 to students and educators. It is online only, in English and Spanish for students. Student participants were from Elementary (Grade 5), Middle (grades 6-8), and High (grades 9-11), and all instructional staff were eligible. The student participation rate was 69.9 percent overall, and the educator participation rate was 76.9 percent.
educator_survey_SY1819educator_survey_SY1819
A data frame with 1,782 rows and 7 variables:
school_numberSchool number
school_nameSchool name
grade_bandGrade band
respondent_grade_bandGrade band of student survey respondents
respondent_countNumber of student survey respondents
domainSurvey domain name
topicSurvey topic name
average_scoreAverage score
There were four domains and ten topics for students, and five domains and eleven topics for educators. Survey results ranged from 1-10, with 10 being most favorable and 1 being least favorable. Schools with fewer than 10 respondents overall or in any topic were excluded from relevant district averages. Cells with an asterisk (*) denote less than 10 students or educators in the summary group. Consequently, all data for that group are suppressed. Survey results are included as an indicator of School Quality and Student Success in the Maryland School Report Card (10 of 100 points: 7 from the student survey, 3 from the educator survey).
https://www.baltimorecityschools.org/data
Total enrollment and demographic characteristics for Baltimore City public school students including data aggregated by grade, grade band, school, and citywide for the 2019-2020 school year.
enrollment_demographics_SY1920enrollment_demographics_SY1920
A data frame with 2,243 rows and 19 variables:
school_numberSchool number
school_nameSchool name
management_typeSchool management type
grade_bandGrade band (factor)
gradeGrade (factor)
grade_rangeGrade range (factor)
total_enrollmentTotal Enrollment
percent_malePercent Males
percent_femalePercent Females
percent_direct_certificationPercent Direct Certification
percent_swdPercent Students with Disabilities (SWD)
percent_elPercent English Learner (EL)
percent_non_hispanic_blackPercent Non-Hispanic Black
percent_non_hispanic_whitePercent Non-Hispanic White
percent_hispanicPercent Hispanic
percent_non_hispanic_asianPercent Non-Hispanic Asian
percent_non_hispanic_american_indianPercent Non-Hispanic American Indian
percent_non_hispanic_pacific_islanderPercent Non-Hispanic Pacific Islander
percent_non_hispanic_multiracialPercent Non-Hispanic Multiracial
For variables with percentages, a value of 0.05 may represent <=5% rather than 5% and a value of 0.95 may represent >=95% rather than 95%.
https://www.baltimorecityschools.org/data
Total enrollment and demographic characteristics for Baltimore City public
school students including data aggregated by grade, grade band, school, and
citywide for the 2019-2020 school year. Long format version is based on the
enrollment_demographics_SY1920 data with an additional label column based
on the original Excel sheet column names.
enrollment_demographics_SY1920_longenrollment_demographics_SY1920_long
A data frame with 26,916 rows and 10 variables:
school_numberSchool number
school_nameSchool name
management_typeSchool management type
grade_bandGrade band
gradeGrade
grade_rangeGrade range
total_enrollmentTotal Enrollment
variableVariable
sharePercent of Total Enrollment
labelVariable label
https://www.baltimorecityschools.org/data
Total enrollment and demographic characteristics for Baltimore City public school students including data aggregated by grade, grade band, school, and citywide for the 2020-2021 school year.
enrollment_demographics_SY2021enrollment_demographics_SY2021
A data frame with 2,192 rows and 19 variables:
school_numberSchool number
school_nameSchool name
management_typeSchool management type
grade_bandGrade band (factor)
gradeGrade (factor)
grade_rangeGrade range (factor)
total_enrollmentTotal Enrollment
percent_malePercent Male
percent_femalePercent Female
percent_direct_certificationPercent Direct Certification
percent_swdPercent Students with Disabilities (SWD)
percent_elPercent English Learner (EL)
percent_non_hispanic_blackPercent Non-Hispanic Black
percent_non_hispanic_whitePercent Non-Hispanic White
percent_hispanicPercent Hispanic
percent_non_hispanic_asianPercent Non-Hispanic Asian
percent_non_hispanic_american_indianPercent Non-Hispanic American Indian
percent_non_hispanic_pacific_islanderPercent Non-Hispanic Native Hawaiian or Other Pacific Islander
percent_non_hispanic_multiracialPercent Non-Hispanic Multiracial
For variables with percentages, a value of 0.05 may represent <=5% rather than 5% and a value of 0.95 may represent >=95% rather than 95%.
https://www.baltimorecityschools.org/data
Total enrollment and demographic characteristics for Baltimore City public school students including data aggregated by grade, grade band, school, and citywide for the 2021-2022 school year.
enrollment_demographics_SY2122enrollment_demographics_SY2122
A data frame with 2,153 rows and 20 variables:
school_numberSchool number
school_nameSchool name
management_typeSchool management type
grade_bandGrade band (factor)
gradeGrade (factor)
grade_rangeGrade range (factor)
total_enrollmentTotal Enrollment
percent_malePercent Male
percent_femalePercent Female
percent_nonbinaryPercent Nonbinary
percent_direct_certificationPercent Direct Certification
percent_swdPercent Students with Disabilities (SWD)
percent_elPercent English Learner (EL)
percent_non_hispanic_blackPercent Non-Hispanic Black
percent_non_hispanic_whitePercent Non-Hispanic White
percent_hispanicPercent Hispanic
percent_non_hispanic_asianPercent Non-Hispanic Asian
percent_non_hispanic_american_indianPercent Non-Hispanic American Indian
percent_non_hispanic_pacific_islanderPercent Non-Hispanic Native Hawaiian or Other Pacific Islander
percent_non_hispanic_multiracialPercent Non-Hispanic Multiracial
The column percent_non_hispanic_pacific_islander is named Percent
non-Hispanic Hawaiian and Other Pacific Islander in the source but is renamed
to match the prior two years of data. This data also includes a
'percent_nonbinary column that is not present in prior years.
For variables with percentages, a value of 0.05 may represent <=5% rather than 5% and a value of 0.95 may represent >=95% rather than 95%.
https://www.baltimorecityschools.org/data
Enrollment data from the Maryland State Department of Education (MSDE). Raw
CSV data files with the full state enrollment data are available in the
inst/extdata folder. The number of enrolled students includes ungraded
special education and pre-kindergarten students. Variable definitions are
based on the definitions from the MSDE website.
enrollment_msde_SY0919enrollment_msde_SY0919
A data frame with 16,763 rows and 6 variables:
school_yearSchool or academic year for enrollment count, e.g. 2019 data is from the start of the 2019-2020 school year.
school_numberSchool number (0 indicates all schools)
school_nameSchool name
enrolled_countNumber of students registered to attend the school as of September 30 in the grade or grade range
gradeGrades from Prekindergarden (PK) to Grade 12
grade_rangeElementary school, middle school, high school, or all grades (total enrollment)
As of 2018-19, students who are not scored (NS) in all items still receive a composite score and readiness level. NS is applied when an item requires demonstration of a skill (e.g., hopping), and the child is not able to respond due to a disability that restricts or prevents participating in the skill being assessed. A NS rating would not be appropriate when the response to the item reflects a child's functioning at an earlier developmental level and their ability to respond is not affected by a disability; in this instance the appropriate rating would be “0” since the child could access the item, but did not demonstrate the skill. See MSDE: KRA 2018-19 Technical Report, January 2019. Consistent with MSDE's reporting, aggregates exclude students with some incomplete items, and include students with not scorable (NS) items. Missing values include data that has been suppressed due to a group size of less than 10 students.
Children whose readiness skills and behaviors are "approaching" or "emerging" overall require instructional support to be successful in kindergarten and beyond. Reports of KRA data prior to the 2018-19 administration have readiness level assigned for each of the four domains (Literacy, Math, Social Foundations, and Physical Development). Since last year's administration, readiness levels are no longer reported for individual domains, and only an overall or composite readiness level is reported. This is why this data file does not resemble previous releases of KRA data. Details on the KRA assessment and changes to the test can be found at https://pd.kready.org/r4kmaryland.
kra_results_SY1920kra_results_SY1920
A data frame with 1604 rows and 13 variables:
school_numberSchool number (0 indicates all schools)
school_nameSchool name
student_groupStudent group (includes "All Students")
group_typeStudent group type
num_tested_scored_overallNumber of test takers with overall scores
avg_scale_scoreAverage KRA scale score
perc_emerging_readinessPercent of test takers in Emerging Readiness category. Emerging readiness: Student demonstrates limited foundational skills and behaviors that prepare him or her for curriculum based on Maryland College and Career-Ready kindergarten standards.
perc_approaching_readinessPercent of test takers in Approaching Readiness category. Approaching readiness: Student demonstrates some foundational skills and behaviors that prepare him or her for curriculum based on Maryland College and Career-Ready kindergarten standards.
perc_demonstrating_readinessPercent of test takers in Demonstrating Readiness category. Demonstrating readiness: Student demonstrates foundational skills and behaviors that prepare him or her for curriculum based on Maryland College and Career-Ready kindergarten standards.
avg_language_and_literacy_scoreAverage score in Literacy domain
avg_math_scoreAverage score in KRA Math domain
avg_physical_development_scoreAverage score in Physical Development domain
avg_social_foundations_scoreAverage score in Social Foundations domain
BCPSS Public 2019-20 KRA School Level Results
NCES Directory listing for Baltimore City Schools including school addresses, phone numbers, and NCES numbers.
nces_school_directory_SY1920nces_school_directory_SY1920
A data frame with 167 rows and 10 variables:
school_yearSchool year
school_numberSchool number
school_nameSchool name
grade_bandGrade band (school type)
addressStreet address
cityCity
stateState
zipZipcode
phonePhone number
nces_numberNCES number
Results from the Baltimore City Public School Parent Survey administered during the for the 2018-2029 school year. Data includes composite scores and responses to selected questions school.
parent_survey_SY1819parent_survey_SY1819
A data frame with 169 rows and 54 variables:
school_numberSchool number
school_nameSchool name
management_typeSchool management type
grade_bandGrade band
parent_response_countTotal parent survey responses
est_num_parentsEstimated number of eligible parents
est_response_rateEstimate parent response rate
administration_dimension_scoreAdministration Dimension Score
creativity_the_arts_dimension_scoreCreativity & the Arts Dimension Score
physical_environment_dimension_scorePhysical Environment Dimension Score
learning_climate_dimension_scoreLearning Climate Dimension Score
family_involvement_dimension_scoreFamily Involvement Dimension Score
school_resources_dimension_scoreSchool Resources Dimension Score
safety_dimension_scoreSafety Dimension Score
satisfaction_with_school_dimension_scoreSatisfaction with School Dimension Score
grit_dimension_scoreGrit Dimension Score
overallOverall Score
district_office_dimension_scoreDistrict Office Dimension Score
admin_1_the_school_administration_promptly_responds_to_my_concernsThe school administration promptly responds to my concerns
admin_9_parents_have_the_opportunity_to_give_input_into_the_school_s_decisionsParents have the opportunity to give input into the school's decisions
creative_1_student_work_in_the_arts_is_displayed_or_presented_in_my_child_s_schoolStudent work in the arts is displayed or presented in my child's school
environ_1_the_school_building_is_clean_and_well_maintainedThe school building is clean and well maintained
learn_13_teachers_care_about_their_studentsTeachers care about their students
learn_14_i_feel_my_child_feels_like_i_belong_at_this_schoolI feel (My child feels) like I belong at this school
learn_18_this_school_prepares_students_for_college_or_to_have_a_careerThis school prepares students for college or to have a career
learn_19_if_students_break_rules_there_are_fair_consequencesIf students break rules, there are fair consequences
parent_1_parents_or_guardians_are_welcome_at_this_schoolParents or guardians are welcome at this school
parent_11_parents_can_use_resources_at_my_child_s_school_when_school_is_not_in_sessionParents can use resources at my child's school when school is not in session
parent_12_i_know_how_to_access_information_about_how_my_child_is_performing_in_school_e_g_parent_portalI know how to access information about how my child is performing in school e.g., Parent Portal
parent_18_the_school_sends_me_information_in_my_native_languageThe school sends me information in my native language
parent_19_i_feel_that_my_input_into_my_child_s_education_is_valuedI feel that my input into my child's education is valued
parent_20_my_child_s_school_can_connect_me_to_resources_in_the_communityMy child's school can connect me to resources in the community
parent_21_the_school_notifies_me_when_my_child_misses_schoolThe school notifies me when my child misses school
parent_23_my_child_s_school_regularly_communicates_with_parents_about_how_they_can_help_their_children_learnMy child's school regularly communicates with parents about how they can help their children learn
parent_3_when_a_student_does_something_good_at_school_the_parents_are_informedWhen a student does something good at school, the parents are informed
parent_4_when_a_student_does_something_bad_at_school_the_parents_are_informedWhen a student does something bad at school, the parents are informed
parent_5_school_staff_work_closely_with_parents_to_meet_students_needsSchool staff work closely with parents to meet students' needs
resource_17_students_have_the_opportunity_to_take_books_home_from_this_schoolStudents have the opportunity to take books home from this school
resource_7_teachers_provide_extra_academic_help_to_students_who_need_itTeachers provide extra academic help to students who need it
resource_9_this_school_has_programs_to_support_students_emotional_and_social_developmentThis school has programs to support students' emotional and social development
safe_12_students_feel_safe_at_this_schoolStudents feel safe at this school
safe_13_students_feel_safe_going_to_and_from_schoolStudents feel safe going to and from school
satisfy_11_overall_i_am_satisfied_with_my_child_s_schoolOverall, I am satisfied with my child's school
satisfy_12_i_would_recommend_this_school_to_othersI would recommend this school to others
grit_6_i_encourage_my_child_to_keep_working_at_difficult_tasks_until_he_she_figures_them_outI encourage my child to keep working at difficult tasks until he/she figures them out
value_1_regular_on_time_attendance_is_important_to_my_child_s_success_in_schoolRegular, on-time attendance is important to my child's success in school
parent_read_2_i_read_with_my_child_at_least_once_a_monthI read with my child at least once a month
parent_talk_2_i_ask_my_child_what_he_she_did_at_school_at_least_once_a_monthI ask my child what he/she did at school at least once a month
district_office_1_if_you_called_the_district_office_within_the_last_year_how_satisfied_were_you_overall_with_the_support_you_receivedIf you called the District Office within the last year, how satisfied were you overall with the support you received?
district_office_2_if_you_visited_district_headquarters_within_the_last_year_how_satisfied_were_you_overall_with_the_service_s_you_requestedIf you visited District Headquarters within the last year, how satisfied were you overall with the services you requested?
transportation_how_does_your_child_usually_get_to_school_walkTransportation: How does your child usually get to school? Walk
transportation_how_does_your_child_usually_get_to_school_school_busTransportation: How does your child usually get to school? School Bus
transportation_how_does_your_child_usually_get_to_school_mta_busTransportation: How does your child usually get to school? MTA Bus
transportation_how_does_your_child_usually_get_to_school_carTransportation: How does your child usually get to school? Car
https://www.baltimorecityschools.org/data
Results from the Baltimore City Public School Parent Survey administered
during the for the 2018-2029 school year. Data includes composite scores and
responses to selected questions school. Long format version is based on the
parent_survey_SY1819 data with an additional label column based on the
original Excel sheet column names.
parent_survey_SY1819_longparent_survey_SY1819_long
A data frame with 7,943 rows and 10 variables:
school_numberSchool number
school_nameSchool name
management_typeSchool management type
grade_bandSchool grade band
parent_response_countNumber of parent survey responses
est_num_parentsEstimated number of eligible parents
est_response_rateEstimated parent response rate
variableUnique slug for composite score or question
valueValue of composite score or share of parents responding affirmatively to question
labelVariable label for composite score or question
https://www.baltimorecityschools.org/data
The Maryland School Survey was administered for the first time in spring 2019 to students and educators. It is online only, in English and Spanish for students. Student participants were from Elementary (Grade 5), Middle (grades 6-8), and High (grades 9-11), and all instructional staff were eligible. The student participation rate was 69.9 percent overall, and the educator participation rate was 76.9 percent.
student_survey_SY1819student_survey_SY1819
A data frame with 17,380 rows and 9 variables:
school_numberSchool number
school_nameSchool name
grade_bandSchool grade band
respondent_grade_bandGrade band of student survey respondents
respondent_countNumber of student survey respondents
respondent_groupSummary group of respondents
domainSurvey domain name
topicSurvey topic name
average_scoreAverage score
There were four domains and ten topics for students, and five domains and eleven topics for educators. Survey results ranged from 1-10, with 10 being most favorable and 1 being least favorable. Schools with fewer than 10 respondents overall or in any topic were excluded from relevant district averages. Cells with an asterisk (*) denote less than 10 students or educators in the summary group. Consequently, all data for that group are suppressed. Survey results are included as an indicator of School Quality and Student Success in the Maryland School Report Card (10 of 100 points: 7 from the student survey, 3 from the educator survey).
Student respondent summary groups include: Students with Disabilities (SWD) ("Special Education Services" in MSDE file): Indicates students who have current Individualized Education Plans (IEPs) and are receiving special education services. English Learner (EL): English Learners, students who have a primary or home language other than English and have been assessed as having limited or no ability to understand, speak, or read English. Economically Disadvantaged (ED): Indicates students who have been identified as enrolled in a direct certification program. Direct certification is based on a student's Supplemental Nutrition Assistance Program (SNAP), Homeless, Foster care, or Temporary Assistance for Needy Families (TANF) status. ED is the new terminology used to refer to students historically identified as low-income or Free and Reduced Meals (FARMS) students under the Every Student Succeeds Act (ESSA).
https://www.baltimorecityschools.org/data